psychopy_ext.exp.Datafile
=========================

.. currentmodule:: psychopy_ext.exp

.. autoclass:: Datafile

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Datafile.__init__
      ~Datafile.close
      ~Datafile.open
      ~Datafile.write
      ~Datafile.write_header
   
   

   
   
   